.. currentmodule:: abjad.tools.pitchtools

transpose_pitch_class_number_to_pitch_number_neighbor
=====================================================

.. autofunction:: transpose_pitch_class_number_to_pitch_number_neighbor
